@@ -61,6 +61,10 @@ __all__ = (
     "KeyPhrasesDetectionJobPropertiesTypeDef",
     "OutputDataConfigTypeDef",
     "PartOfSpeechTagTypeDef",
+    "PiiEntitiesDetectionJobPropertiesTypeDef",
+    "PiiEntityTypeDef",
+    "PiiOutputDataConfigTypeDef",
+    "RedactionConfigTypeDef",
     "SentimentDetectionJobPropertiesTypeDef",
     "SentimentScoreTypeDef",
     "SyntaxTokenTypeDef",
@@ -83,11 +87,13 @@ __all__ = (
     "DescribeEntitiesDetectionJobResponseTypeDef",
     "DescribeEntityRecognizerResponseTypeDef",
     "DescribeKeyPhrasesDetectionJobResponseTypeDef",
+    "DescribePiiEntitiesDetectionJobResponseTypeDef",
     "DescribeSentimentDetectionJobResponseTypeDef",
     "DescribeTopicsDetectionJobResponseTypeDef",
     "DetectDominantLanguageResponseTypeDef",
     "DetectEntitiesResponseTypeDef",
     "DetectKeyPhrasesResponseTypeDef",
+    "DetectPiiEntitiesResponseTypeDef",
     "DetectSentimentResponseTypeDef",
     "DetectSyntaxResponseTypeDef",
     "DocumentClassificationJobFilterTypeDef",
@@ -104,20 +110,24 @@ __all__ = (
     "ListEntitiesDetectionJobsResponseTypeDef",
     "ListEntityRecognizersResponseTypeDef",
     "ListKeyPhrasesDetectionJobsResponseTypeDef",
+    "ListPiiEntitiesDetectionJobsResponseTypeDef",
     "ListSentimentDetectionJobsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "ListTopicsDetectionJobsResponseTypeDef",
     "PaginatorConfigTypeDef",
+    "PiiEntitiesDetectionJobFilterTypeDef",
     "SentimentDetectionJobFilterTypeDef",
     "StartDocumentClassificationJobResponseTypeDef",
     "StartDominantLanguageDetectionJobResponseTypeDef",
     "StartEntitiesDetectionJobResponseTypeDef",
     "StartKeyPhrasesDetectionJobResponseTypeDef",
+    "StartPiiEntitiesDetectionJobResponseTypeDef",
     "StartSentimentDetectionJobResponseTypeDef",
     "StartTopicsDetectionJobResponseTypeDef",
     "StopDominantLanguageDetectionJobResponseTypeDef",
     "StopEntitiesDetectionJobResponseTypeDef",
     "StopKeyPhrasesDetectionJobResponseTypeDef",
+    "StopPiiEntitiesDetectionJobResponseTypeDef",
     "StopSentimentDetectionJobResponseTypeDef",
     "TopicsDetectionJobFilterTypeDef",
 )
@@ -508,6 +518,114 @@ PartOfSpeechTagTypeDef = TypedDict(
     total=False,
 )
 
+PiiEntitiesDetectionJobPropertiesTypeDef = TypedDict(
+    "PiiEntitiesDetectionJobPropertiesTypeDef",
+    {
+        "JobId": str,
+        "JobName": str,
+        "JobStatus": Literal[
+            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
+        ],
+        "Message": str,
+        "SubmitTime": datetime,
+        "EndTime": datetime,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "PiiOutputDataConfigTypeDef",
+        "RedactionConfig": "RedactionConfigTypeDef",
+        "LanguageCode": Literal[
+            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
+        ],
+        "DataAccessRoleArn": str,
+        "Mode": Literal["ONLY_REDACTION", "ONLY_OFFSETS"],
+    },
+    total=False,
+)
+
+PiiEntityTypeDef = TypedDict(
+    "PiiEntityTypeDef",
+    {
+        "Score": float,
+        "Type": Literal[
+            "BANK_ACCOUNT_NUMBER",
+            "BANK_ROUTING",
+            "CREDIT_DEBIT_NUMBER",
+            "CREDIT_DEBIT_CVV",
+            "CREDIT_DEBIT_EXPIRY",
+            "PIN",
+            "EMAIL",
+            "ADDRESS",
+            "NAME",
+            "PHONE",
+            "SSN",
+            "DATE_TIME",
+            "PASSPORT_NUMBER",
+            "DRIVER_ID",
+            "URL",
+            "AGE",
+            "USERNAME",
+            "PASSWORD",
+            "AWS_ACCESS_KEY",
+            "AWS_SECRET_KEY",
+            "IP_ADDRESS",
+            "MAC_ADDRESS",
+            "ALL",
+        ],
+        "BeginOffset": int,
+        "EndOffset": int,
+    },
+    total=False,
+)
+
+_RequiredPiiOutputDataConfigTypeDef = TypedDict(
+    "_RequiredPiiOutputDataConfigTypeDef", {"S3Uri": str}
+)
+_OptionalPiiOutputDataConfigTypeDef = TypedDict(
+    "_OptionalPiiOutputDataConfigTypeDef", {"KmsKeyId": str}, total=False
+)
+
+
+class PiiOutputDataConfigTypeDef(
+    _RequiredPiiOutputDataConfigTypeDef, _OptionalPiiOutputDataConfigTypeDef
+):
+    pass
+
+
+RedactionConfigTypeDef = TypedDict(
+    "RedactionConfigTypeDef",
+    {
+        "PiiEntityTypes": List[
+            Literal[
+                "BANK_ACCOUNT_NUMBER",
+                "BANK_ROUTING",
+                "CREDIT_DEBIT_NUMBER",
+                "CREDIT_DEBIT_CVV",
+                "CREDIT_DEBIT_EXPIRY",
+                "PIN",
+                "EMAIL",
+                "ADDRESS",
+                "NAME",
+                "PHONE",
+                "SSN",
+                "DATE_TIME",
+                "PASSPORT_NUMBER",
+                "DRIVER_ID",
+                "URL",
+                "AGE",
+                "USERNAME",
+                "PASSWORD",
+                "AWS_ACCESS_KEY",
+                "AWS_SECRET_KEY",
+                "IP_ADDRESS",
+                "MAC_ADDRESS",
+                "ALL",
+            ]
+        ],
+        "MaskMode": Literal["MASK", "REPLACE_WITH_PII_ENTITY_TYPE"],
+        "MaskCharacter": str,
+    },
+    total=False,
+)
+
 SentimentDetectionJobPropertiesTypeDef = TypedDict(
     "SentimentDetectionJobPropertiesTypeDef",
     {
@@ -682,6 +800,12 @@ DescribeKeyPhrasesDetectionJobResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribePiiEntitiesDetectionJobResponseTypeDef = TypedDict(
+    "DescribePiiEntitiesDetectionJobResponseTypeDef",
+    {"PiiEntitiesDetectionJobProperties": "PiiEntitiesDetectionJobPropertiesTypeDef"},
+    total=False,
+)
+
 DescribeSentimentDetectionJobResponseTypeDef = TypedDict(
     "DescribeSentimentDetectionJobResponseTypeDef",
     {"SentimentDetectionJobProperties": "SentimentDetectionJobPropertiesTypeDef"},
@@ -708,6 +832,10 @@ DetectKeyPhrasesResponseTypeDef = TypedDict(
     "DetectKeyPhrasesResponseTypeDef", {"KeyPhrases": List["KeyPhraseTypeDef"]}, total=False
 )
 
+DetectPiiEntitiesResponseTypeDef = TypedDict(
+    "DetectPiiEntitiesResponseTypeDef", {"Entities": List["PiiEntityTypeDef"]}, total=False
+)
+
 DetectSentimentResponseTypeDef = TypedDict(
     "DetectSentimentResponseTypeDef",
     {
@@ -869,6 +997,15 @@ ListKeyPhrasesDetectionJobsResponseTypeDef = TypedDict(
     total=False,
 )
 
+ListPiiEntitiesDetectionJobsResponseTypeDef = TypedDict(
+    "ListPiiEntitiesDetectionJobsResponseTypeDef",
+    {
+        "PiiEntitiesDetectionJobPropertiesList": List["PiiEntitiesDetectionJobPropertiesTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
+)
+
 ListSentimentDetectionJobsResponseTypeDef = TypedDict(
     "ListSentimentDetectionJobsResponseTypeDef",
     {
@@ -897,6 +1034,19 @@ PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
 
+PiiEntitiesDetectionJobFilterTypeDef = TypedDict(
+    "PiiEntitiesDetectionJobFilterTypeDef",
+    {
+        "JobName": str,
+        "JobStatus": Literal[
+            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
+        ],
+        "SubmitTimeBefore": datetime,
+        "SubmitTimeAfter": datetime,
+    },
+    total=False,
+)
+
 SentimentDetectionJobFilterTypeDef = TypedDict(
     "SentimentDetectionJobFilterTypeDef",
     {
@@ -954,6 +1104,17 @@ StartKeyPhrasesDetectionJobResponseTypeDef = TypedDict(
     total=False,
 )
 
+StartPiiEntitiesDetectionJobResponseTypeDef = TypedDict(
+    "StartPiiEntitiesDetectionJobResponseTypeDef",
+    {
+        "JobId": str,
+        "JobStatus": Literal[
+            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
+        ],
+    },
+    total=False,
+)
+
 StartSentimentDetectionJobResponseTypeDef = TypedDict(
     "StartSentimentDetectionJobResponseTypeDef",
     {
@@ -1009,6 +1170,17 @@ StopKeyPhrasesDetectionJobResponseTypeDef = TypedDict(
     total=False,
 )
 
+StopPiiEntitiesDetectionJobResponseTypeDef = TypedDict(
+    "StopPiiEntitiesDetectionJobResponseTypeDef",
+    {
+        "JobId": str,
+        "JobStatus": Literal[
+            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
+        ],
+    },
+    total=False,
+)
+
 StopSentimentDetectionJobResponseTypeDef = TypedDict(
     "StopSentimentDetectionJobResponseTypeDef",
     {
